package com.googlecode.alfresco.repository.query;

/**
 * Defines operations for resolving {@link Query} variables. Typically used by {@link QuerySerializer}s when the
 * corresponding query language format.
 * <p>
 * If a variable cannot be resolved, callers should typically omit the variable's condition and any preceding logical
 * operation from the generated query.
 *
 * @author Laurens Fridael
 */
public interface VariableResolver {

	/**
	 * Resolves a given Variable.
	 *
	 * @param variable
	 *            The resolved value or null if the value could not be resolved.
	 * @return
	 * @throws IllegalArgumentException
	 *             If variable is null or an empty String.
	 */
	public Object resolveVariable(String name);
}
