package com.googlecode.alfresco.repository.query.impl;

/**
 * Enum representing predefined queryable fields. See the <a href="http://wiki.alfresco.com/wiki/Search">Search page on
 * the Alfresco Wiki</a> for more information.
 * <p>
 * In most cases, the enum names are identical to the query field names. However, for word combinations such as
 * {@link #IS_NOT_NULL}, the enum names use underscores, while the field names have the words packed together. In this
 * particular example the corresponding field name is &quot;ISNOTNULL&quot;.
 *
 * @author Laurens Fridael
 */
public enum Field {
	TEXT, ID, IS_ROOT("ISROOT"), IS_NODE("ISNODE"), TX, PARENT, PRIMARY_PARENT("PRIMARYPARENT"), QNAME, CLASS, TYPE, EXACT_TYPE(
			"EXACTTYPE"), ASPECT, EXACT_ASPECT("EXACTASPECT"), ALL, IS_UNSET("ISUNSET"), IS_NULL("ISNULL"), IS_NOT_NULL(
			"ISNOTNULL"), PATH, PATH_WITH_REPEATS;

	private String fieldName;

	/**
	 * Constructs an instance where the query field name and enum name are identical.
	 */
	private Field() {
		this.fieldName = name();
	}

	/**
	 * Constructs an instance where the query field name can be different from the enum name.
	 *
	 * @param fieldName
	 */
	private Field(final String fieldName) {
		this.fieldName = fieldName;
	}

	/**
	 * Obtains the query field name.
	 *
	 * @return The field name.
	 */
	public String getFieldName() {
		return fieldName;
	}
}
